# 5. Prejudice

> PSYG2504 Social Psychology

## 5.1 Stereotype, prejudice and discrimination

### 5.1.1 Examples of Prejudice

- **Sex: Also known as sexism**.  
  Women face discrimination in work settings, higher education and government (e.g. Fisher, 1992).
- **Sexual orientation: Sometimes called heterosexism**.  
  Most adult in the US hold negative attitudes toward homosexual behavior, regarding it as wrong and unnatural (Herek & Capitanio, 1996; Yang, 1997).
- **Age**:  
  Elderly people are often assumed to be less capable physically and mentally (Levy & Langer, 1994)
- **Weight: Sometimes called “size discrimination”.**
  Overweight people are perceived as less attractive, less intelligent, less happy, less self-disciplined, and less successful (Hebl & Heatherton, 1998).
- **Physical attractiveness: Also known as appearance prejudice.**
  Physically attractive people receive more lenient punishments (Mazzella & Feingold, 1994).

## 5.2 Components of Group Antagonism

- Stereotypes (cognitive)
  A belief about the personal attributes of a group of people
  Can be overgeneralized, inaccurate, and resistant to new information
- Prejudice (attitudinal)
  A negative prejudgment/emotional responses of a group and its individual members
- Discrimination (behavioral)
  Unjustifiable negative behavior toward a group or its members

### 5.2.1 Stereotypes

*A generalization about a group of people in which certain traits are assigned to virtually all members of the group, regardless of actual variation among the members.*

- **Based on experience and accurately identifies certain attributes of a group overall.**  
  Adaptive, shortcuts to deal with complex situations.
- **May have a “grain of truth”**  
  e.g. crime and welfare rates are in fact relatively higher for African Americans.
- But some do not…
  - **Over-generalized**  
    e.g. all men are aggressive.
  - **Overemphasize negative attributes**  
    e.g. women are emotional; men are emotionally heartless.

*Stereotypes exert strong effects on how we process social information.*

**Perception:**

> Sagar and Schofield (1980) showed sixth graders drawing between 2 children whose races were systematically varied.  
> They described the behavior as more mean and threatening when black children were involved than white children.

Information relevant to an activated stereotype is often processed more quickly, and remembered better, than information unrelated to it (Macrae et al., 1997).  
Inconsistent information may be refuted or changed in subtle ways to make it consistent (Kunda & Oleson, 1995)

### 5.2.2 Prejudice

*The evaluation (usually negative) of a group or an individual based mainly on group membership.*

- **A kind of prejudgment.**  
  e.g. Alice is not a competent manager because she is a woman (before you try to understand her ability).
- **Can contain a negative affect/emotion**  
  e.g. strongly upset as Alice is the manager.

In the real world, prejudice and stereotyping tend to go together.  
e.g. those who are prejudiced against gay people are likely to have a stereotype of gay such as immoral or low self-esteem.

We see only the information that confirms how right we are about “those people” and dismiss information that might require us to change our minds

### 5.2.3 Discrimination

*Unjustified negative or harmful action toward a member of a group solely because of his/her membership in that group.*  
Negative actions toward the objects of racial, ethnic, or religious prejudice have decreased somewhat in recent years in the US and many other countries.

In fact, “old-fashioned” racism, for instance, is simply replaced by modern racism (more subtle) (Swim et al., 1995).  
Involves concealing prejudice from others in public settings, but expressed bigoted attitudes when it is safe to do so.

## 5.3 The causes of prejudice

Perceived threat to a valued group

- Conformity – living in a society where stereotypical information abounds and where discriminatory behavior is the norm
- Realistic group conflict theory
- Social identity theory – Feeling Superior to Others

### 5.3.1 Intergroup competition

**Realistic group conflict theory:**
*The idea that limited resources lead to conflict between groups and result in increased prejudice and discrimination (Jackson, 1993).*

- Stem from competition among social groups over valued commodities or opportunities.
- Competition intensifies conflict (Sherif, Harvey, White, Hood & Sherif, 1961).
- The competition may finally develop into full scale, emotion-laden prejudice.

### 5.3.2 Social identity theory

![Screenshot_20240511_233807.jpg](https://photo-1303301880.cos.ap-guangzhou.myqcloud.com/2024/05/11/663f90ed33358.jpg)

#### Assumptions of Social Identity Theory (Tajfel, 1982)

1. **We categorize:** We find it useful to put people,    ourselves included, into categories.
2. **We identify:** We associate ourselves with certain groups (ingroups) and gain self-esteem by doing so.
3. **We compare:** we contrast our groups with other groups (outgroups), with a favorable bias toward our own group.

#### The act of categorization can group people as “us” (an ingroup) or “them” (an outgroup)

The part of a person’s self-concept that is based on his/her identification with a nation, religious or political group, occupation, or other social affiliation.

- **In-group favoritism effect/In-group bias (Tajfel et al., 1971)**:
   The positive feeling and special treatment we give to people we have defined as being part of our in-group (leads to unfair treatment of others merely because we defined them as being in the out-group).
- **group-serving biases**:
  Explaining away outgroup members positive behaviors; also attributing negative behaviors to their dispositions (while excusing such behavior by one’s own group).  
  E.g. A donating behavior: In-group members: She donated because she has a good heart; Out-group members: She donated to gain favor.
- **The assumed-similarity effect**:
  Other in-group members are seen as more similar to the self than out-group members.  
  Allen and Wilder (1979) made students believe that they were grouped accordingly to artistic preference (in fact, randomly) and found that students assumed other ingroup members were more similar to them than outgroup members even on matters unrelated to art.
- **The outgroup homogeneity effect**:
  Perceptions of outgroup members are more similar to one another than are ingroup members.  
  “They are all alike, while we are diverse.”
  The greater our familiarity with a social group, the more we see its diversity; The less our familiarity, the more we stereotype (Brown & Wootton-Millward, 1993).
  E.g. Many non-Europeans see the Swiss as a fairly homogeneous people; but to the people of the Switzerland, the Swiss are diverse, encompassing French-, German-, Italian-, and Romansh-speaking groups 

![Screenshot_20240511_233752.jpg](https://photo-1303301880.cos.ap-guangzhou.myqcloud.com/2024/05/11/663f90edb1561.jpg)

### 5.3.3 Social learning

*We acquire negative attitudes towards other social groups by hearing such views expressed by significant others.*   
There are directly rewards for adopting the same views (e.g. love, approval).

#### Socialization
*A process by which children learn the conventional social norms from family
Our families and cultures pass on all kinds of information.* (e.g. finding mates, whom to trust and dislike).

> Swedish teens display increasing anti-immigrant prejudice over time if their parents voice such prejudice (Miklikowska, 2017).   
> Parental attitudes assessed shortly after their babies are born predict their children attitudes 17 years later (Fraley et al., 2012).

#### The Media

*Media coverage reflects and reinforces stereotypes.*  
e.g. Gilens (1999) found that the media presents an inaccurate picture of people on welfare, showing them as much more likely to be black and unemployed than is the case in reality

### 5.3.4 Cognitive Bases of Prejudice

Cognitive biases occur because we need to simplify a complex world. These biases can produce stereotypes and prejudice even in the absence of socialization or competition between groups.

- We have a natural tendency to categorize in order to simplify our environment.
- People categorize others into groups on the basis of perceptually salient characteristics .    
  race, gender, language, or even accent 
  Taylor et al. (1978) asked subjects to view different people making different statements.  They often forgot who said what, yet they remembered the race of the person who made each statement 
- Social norms provide a basis for categorization based on other attributes.  
  e.g. social class

## 5.4 Reducing prejudice
### 5.4.1 Socialization

*Much change is happening spontaneously as target groups change and levels of education rise.*

More education people have, the less prejudiced they are likely to be (esp. for people with college degrees) (Schuman et al., 1997).
Simple media persuasion seems not effective (see Hovland, 1959)

### 5.4.2 Intergroup contact

*Contact hypothesis: The view that social interactions between social groups would reduce prejudice.*

Blacks and whites are still quite segregated in the U.S.
Half the white population live in neighborhoods that have no African Americans within half a mile
Only 1/5 of whites have at least one black friend (e.g. Jackman & Crane, 1986)
Most white soldiers initially opposed desegregation reduced opposition after it (Pettigrew, 1958)
Several surveys in Europe found that having more friends in minority groups was associated with less prejudice (Pettigrew, 1997)

**Gordon Allport’s (1954) contact theory:**

- **Equality of status**: the groups must have roughly equal status in the situation.
- **Common goals**: the people in the situation should be working towards a goal that both groups share.
- **Intergroup cooperation**: the two groups’ pursuit of common goals should be based on cooperation, rather than competition, between their members.
- **Institutional support**: legitimacy on the contact situation, and establishes that acceptance between groups is the norm.

Intergroup contact is likely to decrease prejudice only if the conditions of Allport’s theory are met.  
e.g. merely putting students of different groups together in a class does not work

However, many efforts at intergroup contact do not meet the conditions.
Even in desegregated schools, children tend to associate more with their own race (Schofield, 1978)

### 5.4.3 Recategorization

*A shift in the boundary between the in-group (us) and some out-group (them).*

Gaertner et al. (1990) suggest helping people to experience working together cooperatively can induce people belonging to different groups to perceive each other as members of a single group.  
e.g., your identity changes from Psychology major students in CIE to HKBU student.

## 5.5 The case of HK

### 5.5.1 Minority Groups in HK

- Mentally retarded  
  Chronically ill patients
- Autistic  
  New immigrants
- Physically handicapped  
  Blind, Deaf, Limps
- Indian/Pakistani/Filipino
- Sex workers & HIV infected

### 5.5.2 Work of EOC in Hong Kong

The Equal Opportunities Commission (EOC) is a statutory body set up in 1996 to implement the Sex Discrimination Ordinance (SDO) 《性別歧視條例》, the Disability Discrimination Ordinance (DDO) 《殘疾歧視條例》and the Family Status Discrimination Ordinance (FSDO) 《家庭崗位歧視條例》

The Commission works towards the elimination of discrimination on the grounds of sex, marital status, pregnancy, disability and family status