# 7. Conformity and compliance

> PSYG2504  Social psychology

## 7.1 Compliance

### 7.1.1 What is compliance (遵守)?

*Compliance increased even though the explanation provided no logical justification.*

“Mindless conformity”.
The response is made almost without thinking.
We spare the mental effort of thinking and simply comply with the situation.

#### Underlying Principles (Cialdini, 1994)

1. **Friendship/liking** – we are willing to comply with requests from friends and from people we like.
2. **Commitment/consistency** - once committed to a position/action, more willing to comply with requests for behaviors that are consistent with the position/action.
3. **Reciprocity** - we feel compelled to pay back ; we are more likely to comply with a request from someone who has previously helped us.
4. **Scarcity** – we comply with requests that are scarce or decreasing in availability.
5. **Authority** – we comply with requests that are from someone who holds legitimate authority (obedience).
6. **Social validation** - We want to be correct: we act or think like others (conformity).

### 7.1.2 Compliance techniques?

#### Technique based on liking Ingratiation

A persuasive technique that involves making the persuasive target like you in order to persuade them by

- Agreeing with them
- Flattering them
- Being nice to them
- But may backfire if the ingratiation is too obvious

#### Techniques based on commitment or consistency

##### Foot-in-the-Door Technique
*First make a small request (usually so trivial that it is hard to refuse, e.g. free sample) and then follow with a larger request.*
It may not work if the first request is too small and the second request is too large 

- Self-perception theory – the individual’s self-image changes (e.g. they are agreeable person) as a result of the initial act of compliance.
- Desire to be consistent – especially for those who express a strong personal preference for consistency.

##### Door-in-the-Face Technique
*First make a large and unrealistic request before making a smaller, more realistic request.*

> Cialdini et al. (1975) stopped college students on the street and asked them to serve as unpaid counselors for juvenile delinquents 2 hours a week for 2 years (83% said no)
> Scaled down to a 2-hour trip to the zoo with a group of such adolescent (50% agreed!)

#### Techniques based on reciprocity
##### That’s-Not-All Technique
*First make a large request, then throwing in some ‘added extras’ to pressure the target to reciprocate (e.g. discount, bonus).*

>  Burger’s (1986) tried to sell one cupcake and two cookies for 75 cents to students on campus
> Control: a prepackaged (1 cupcake & 2 cookies) set for 75 cents
> Experimental: 75 cents for the cupcake and then 2 FREE cookies!
> Results: 40% Vs. 73%.

Persons on the receiving end view the “extra” as an added concession, and feel obligated to make a concession themselves.

##### Playing Hard to Get Technique
*Suggesting a person or object is scarce and hard to obtain.*

Commonly observed in the area of romance.
Shown to be effective in job hunting (William et al., 1993).

##### Deadline Technique
*Targets are told that they have only limited time to take advantage of some offer or to obtain some items.*

### 7.1.3 How to resist compliance?

**Reactance theory (Brehm, 1966):**  
*A negative reaction to an influence attempt that threatens personal freedom*
*Bensley and Wu (1991).*

studied anti-drinking messages of 2 intensities:

- Strong: there is “conclusive evidence” of the harm of drinking and that “any reasonable person must acknowledge these conclusions”.
- Mild: there is “good evidence” and “you may wish to carefully consider” these findings.

In a first study, average students reported that they intended to drink less in the coming few days after reading the mild message
In a second study, fairly heavy alcohol drinkers (college students) actually consumed more beer after reading the strong message

## 7.2 Obedience
### 7.2.1 What is obedience?

*An extreme form of social influence involved changing your opinions, judgments, or actions because someone in a position of authority told you to.*  
Obedience is based on the belief that authorities have the right to make requests.

### 7.2.2 Milgram’s experiment

Milgram was interested in the point at which people would disobey the experimenter in the face of the learner’s protests.

#### Method

- The learner mentions that he has a slightly weak heart
- You control an electric shock machine
- When he is wrong, you have to punish him: first by “15 Volts - Slight Shock” and in the end, “450 Volts - XXX”

Sample of the learner’s schedule of protests (recording)

- 75V: Ugh!
- 165V: Ugh! Let me out! (Shouting)
- 270V: (Screaming) Let me out of here (3 times). Let me out. Do you hear? Let me out of here.
- 285V: (Screaming)
- 315V: (Intense screaming) I told you I refuse to answer. I’m no longer part of this experiment.
- (No more sound in the end)

The experiment’s script

- Please continue.
- The experiment requires that you continue.
- It is absolutely essential that you continue.
- You have no other choice; you MUST go on.

#### Disscussion

- imagine you are in Yale Univ. Psy. Dept. 
- the experiment is about the effect of punishment on learning
- You and another person are teacher and learner
- You have to read aloud pairs of words that the learner has to memorize 

The Milgram experiments illustrate what he called the “normality thesis”.
The idea that evil acts are not necessarily performed by abnormal or “crazy” people.
He also succeeded in illustrating the power of social situations to influence human behavior.
His findings were replicated in different countries (e.g., Jordan, Germany, Australia) and with children as well as adults (e.g. Shanab & Yahya, 1977).

### 7.2.3 Determinants of obedience

#### Emotional distance of the victim
When the victim is remote and the ‘teachers’ heard no complaints, all teachers obeyed calmly to the end.
But when the learner was in the same room, ”only” 40% obeyed to 450 volts.

#### Closeness and legitimacy of the authority
When the experimenter is physically close to the ‘teachers’, the compliance increases (if by phone, only 21% fully obeyed).
Given that the experimenter must be perceived as the authority or legitimate.

#### Institutional authority
 The reputation/prestige leads to the obedience.
#### The liberating effects of group influence
Milgram placed two confederates to help to conduct the experiment.
Both confederates defied the experimenter.
The real participant did not continue the experiment.

## 7.3 Conformity
### 7.3.1 What is conformity?

*The desire to be accepted and to avoid rejection from others leads us to conform.*
Conformity due to normative influence generally changes public behavior but not private beliefs.

e.g. speak politely in front of me but swear among the classmates/friends
However, through dissonance reduction, a behavioral change can lead to a change in beliefs

### 7.3.2 Asch’s experiment?

>  Subjects’ task was to pick the line on the left that best matched the target line on the right in length.
> Alone, people virtually never erred.  But when four or five others before them gave the wrong answer, people erred about 35% of the time. 75% of subjects conformed at least once.

### 7.3.3 Why conform?

*Others’ behavior often provides useful information.*

- Trust in the group affects conformity
- Task difficulty affects conformity

**Informational Influence**: The Desire to Be Right

**Normative Influence**: 

- **The Desire to Be Liked**
- **Norm**: an understood rule for accepted and expected behavior; prescribes “proper” behavior.

### 7.3.4 When conform?

1. **Group Size**  
   The larger the group, the more conformity—to a point (beyond 5 would diminish returns).
   Gerard et al. (1968) found that 3-5 people elicit more conformity than just 1-2 people.
2. **Group Unanimity**  
   Even one dissenter dramatically drops conformity (Allen & Levine, 1969).
3. **Status**   
   People of lower status accepted the experimenter’s commands more readily than people of higher status.
4. **Cohesion **   
   A “we feeling”.
   The more cohesive group is, the more power it gains over its members.
5. **Public response**  
   People conform more when they must respond in front of others rather than writing their answers privately.